==> xlniuxdata-vipgame-1.0.33-20151112.053636-31-sources.jar: com/xunlei/niux/data/vipgame/facade/IFacade.java <==
package com.xunlei.niux.data.vipgame.facade;

import com.xunlei.niux.data.vipgame.bo.*;
import com.xunlei.niux.data.vipgame.bo.account.PreRegisterAccountBo;
import com.xunlei.niux.data.vipgame.bo.activity.CompanyQqOpenRecordBo;
import com.xunlei.niux.data.vipgame.bo.activity.CouponBo;
import com.xunlei.niux.data.vipgame.bo.activity.secondkill.SecondKillConfigBo;
import com.xunlei.niux.data.vipgame.bo.authority.AuthInfoBo;
import com.xunlei.niux.data.vipgame.bo.bonus.AuctionProductBo;
import com.xunlei.niux.data.vipgame.bo.bonus.AuctionRecordBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BaseProductBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusChargeBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusChargeRecordBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusExchangeBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusOperateRecordBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusProductGiveOutDayStatisticsBo;
import com.xunlei.niux.data.vipgame.bo.bonus.ExchangeTransBo;
import com.xunlei.niux.data.vipgame.bo.bonus.SignDayNumBo;
import com.xunlei.niux.data.vipgame.bo.bonus.SignRecordBo;
import com.xunlei.niux.data.vipgame.bo.businesss.*;
import com.xunlei.niux.data.vipgame.bo.gamepoint.GamePointBo;
import com.xunlei.niux.data.vipgame.bo.gamepoint.UserGradePointBo;
import com.xunlei.niux.data.vipgame.bo.games.MobileGamePicBo;
import com.xunlei.niux.data.vipgame.bo.gift.GiftBo;
import com.xunlei.niux.data.vipgame.bo.gift.GiftRecordBo;
import com.xunlei.niux.data.vipgame.bo.gift.UseGiftPackageBo;
import com.xunlei.niux.data.vipgame.bo.jifenshop.JiFenRewardRecordBo;
import com.xunlei.niux.data.vipgame.bo.lottery.FortuneGiftBo;
import com.xunlei.niux.data.vipgame.bo.lottery.FreeLotteryChanceBo;
import com.xunlei.niux.data.vipgame.bo.lottery.LotteryRecordBo;
import com.xunlei.niux.data.vipgame.bo.moyu.*;
import com.xunlei.niux.data.vipgame.bo.openserver.OpenServerBo;
import com.xunlei.niux.data.vipgame.bo.pay.PayOrderBo;
import com.xunlei.niux.data.vipgame.bo.pay.RechargeRecordBo;
import com.xunlei.niux.data.vipgame.bo.tasks.TaskDutyConfigBo;
import com.xunlei.niux.data.vipgame.bo.tasks.TaskGameConfigBo;
import com.xunlei.niux.data.vipgame.bo.tasks.UserTaskRecordBo;
import com.xunlei.niux.data.vipgame.bo.version.GameVersionBo;
import com.xunlei.niux.data.vipgame.bo.version.VersionInfoBo;

import com.xunlei.niux.data.vipgame.bo.gift.GiftFlowBo;
import com.xunlei.niux.data.vipgame.bo.vic.CustomerBo;
import com.xunlei.niux.data.vipgame.bo.vic.KpiBo;
import com.xunlei.niux.data.vipgame.bo.vic.RebateReportBo;
import com.xunlei.niux.data.vipgame.bo.vic.SmsSendApplyBo;


public interface IFacade {
	CouponBo getCouponBo();
	FortuneBo getFortuneBo();
    GameContentBo getGameContentBo();
    UseGiftPackageBo getUseGiftPackageBo();
    GameImgBo getGameImgBo();

    GameExpandBo getGameExpandBo();

    GameScreenshotImageBo getGameScreenshotImageBo();

    GamesBo getGamesBo();

    GameServersBo getGameServersBo();

    SpreadinfoBo getSpreadinfoBo();

    PageStatisticsJsBo getPageStatisticsJsBo();

    LinkInfoBo getLinkInfoBo();

    LinkLocationBo getLinkLocationBo();

    HtmlTemplateBo getHtmlTemplateBo();

    TemplateSchemaBo getTemplateSchemaBo();

    SpreadInfoTimeBo getSpreadInfoTimeBo();

    GamePayInfoBo getGamePayInfoBo();

    GameInsideplaceBo getGameInsideplaceBo();

    UserFeedbackBo getUserFeedbackBo();

    MoyoServerBo getMoyoServerBo();

    MoyuActBo getMoyuActBo();

    MoyuJiFenBo getMoyuJiFenBo();

    MoyuJiFenHistoryBo getMoyuJiFenHistoryBo();
    
    InterfaceManBo getInterfaceManBo();
    
    CallRecordBo getCallRecordBo();
    
    ChargeAmountProfileSettingsBo getChargeAmountProfileSettingsBo();

    MoyuExchangeBo getMoyuExchangeBo();
    TempPasswordBo getTempPasswordBo();
    ForbidUserBo getForbidUserBo();

    MoyuGiftBo getMoyuGiftBo();

    MoyuReportBo getMoyuReportBo();
    
    BigCustomerQueryBo getBigCustomerQueryBo();
    
    BigCustomerDetailBo getBigCustomerDetailBo();

    MoyuTotalReportBo getMoyuTotalReportBo();
    MoyuDayReportBo getMoyuDayReportBo();
    MoyuDetailReportBo getMoyuDetailReportBo();

    CorporationInfoBo getCorporationInfoBo();
    ResponsiblePeopleBo getResponsiblePeopleBo();
    TestAcountBo getTestAcountBo();
    IntoSystemBo getIntoSystemBo();
    IncomeBo getIncomeBo();
    IncomeAppBo getIncomeAppBo();
    TestIncomeBo getTestIncomeBo();

    SendMailRecordBo getSendMailRecordBo();
    ActivityBo getActivityBo();
    BigActVoteDetailBo getBigActVoteDetailBo();
    QuestionSettingsBo getQuestionSettingsBo();
    QuestionBo getQuestionBo();
    QuestionReplyBo getQuestionReplyBo();
    QuestionItemBo getQuestionItemBo();
    QuestionGameCategoryBo getQuestionGameCategoryBo();
    GameCategoryBo getGameCategoryBo();
    PayOrderBo getPayOrderBo();
    RechargeRecordBo getRechargeRecordBo();
    UserInfoExpandBo getUserInfoExpandBo();
    AdviceBo getAdviceBo();

    PrizeBo getPrizeBo();
    SignRecordBo getSignRecordBo();
    BonusProductBo getBonusProductBo();
    BonusChargeRecordBo getBonusChargeRecordBo();
    BonusOperateRecordBo getBonusOperateRecordBo();
    BonusChargeBo getBonusChargeBo();
    SignDayNumBo getSignDayNumBo();
    ExchangeTransBo getExchangeTransBo();
    BonusProductGiveOutDayStatisticsBo getBonusProductGiveOutDayStatisticsBo();
    WhiteListBo getWhiteListBo();
    CustomerGradeBo getCustomerGradeBo();
    CustomerPayBo getCustomerPayBo();
    CustomerPersistBo getCustomerPersistBo();
    CustomerTotalBo getCustomerTotalBo();
    CustomerQueryBo getCustomerQueryBo();
    CustomerInfoBo getCustomerInfoBo();
    CustomerDetailQueryBo getCustomerDetailQueryBo();
    CustomerBigPayQueryBo getCustomerBigPayQueryBo();
    MobileBindActBo getMobileBindActBo();
    VersionInfoBo getVersionInfoBo();
    GameVersionBo getGameVersionBo();
    FavoriteRecordBo getFavoriteRecordBo();
    CommonAskBo getCommonAskBo();
    YyQuestionBo getYyQuestionBo();
    CardDistributionBo getCardDistributionBo();
    CardBiziBo getCardBiziBo();
    CardCountBo getCardCountBo();
    CardUseRecordBo getCardUseRecordBo();
    CardRecordDetailBo getCardRecordDetailBo();
    MessageBo getMessageBo();
    CounterAttackBo getCounterAttackBo();
    LiveCountBo getLiveCountBo();
    UserMessageBo getUserMessageBo();
    SignStatisticsBo getSignStatisticsBo();
    TimeTaskRecordBo getTimeTaskRecordBo();
    GameXmlMetaBo getGameXmlMetaBo();
    GamePayXmlMetaBo getGamePayXmlMetaBo();
    GameActivityXmlMetaBo getGameActivityXmlMetaBo();
    AutoProductBo getAutoProductBo();
    AutoCountBo getAutoCountBo();
    BlackIpBo getBlackIpBo();
    TestAccountBo getTestAccountBo();
    BonusLotRecordBo getBonusLotRecord();
    BonusExchangeBo getBonusExchangeBo();
    MemberGiftBo getMemberGiftBo();
    MemberReceiveBo getMemberReceiveBo();
    CheckUserBo getCheckUserBo();
    MarketProductBo getMarketProductBo();
    CompanyQqOpenRecordBo getCompanyQqOpenRecordBo();
    ActivityExchangeProductBo getActivityExchangeProductBo();
    ActivityExchangeRecordBo getActivityExchangeRecordBo();
    AuctionProductBo getAuctionProductBo();
    AuctionRecordBo getAuctionRecordBo();
    BaseProductBo getBaseProductBo();
    CustomerChangeInfoBo getCustomerChangeInfoBo();
    BaseSo getBaseSo();
    AuthInfoBo getAuthInfoBo();
    TriggerMessageBo getTriggerMessageBo();
    SeoLinkBo getSeoLinkBo();
    FortuneGiftBo getFortuneGiftBo();
    LotteryGiftBo getLotteryGiftBo();
    RebateOrderBo getRebateOrderBo();

    FreeLotteryChanceBo getFreeLotteryChanceBo();
    PreRegisterAccountBo getPreRegisterAccountBo();
    OpenServerBo getOpenServerBo();
    GiftRecordBo getGiftRecordBo();
    SecondKillConfigBo getSecondKillConfigBo();

    UserTaskRecordBo getUserTaskRecordBo();
    TaskDutyConfigBo getTaskDutyConfigBo();

    TaskGameConfigBo getTaskGameConfigBo();

    GiftBo getGiftBo();

    GiftFlowBo getGiftFlowBo();

    GamePointBo getGamePointBo();

    UserGradePointBo getUserGradePointBo();

    LotteryRecordBo getLotteryRecordBo();

    JiFenRewardRecordBo getJiFenRewardRecordBo();

    MobileGamePicBo getMobileGamePicBo();

    KpiBo getKpiBo();

    RebateReportBo getRebateReportBo();

    SmsSendApplyBo getSmsSendApplyBo();

    CustomerBo getCustomerBo();
}

==> xlniuxdata-vipgame-1.0.43-20160105.123442-5-sources.jar: com/xunlei/niux/data/vipgame/facade/IFacade.java <==
package com.xunlei.niux.data.vipgame.facade;

import com.xunlei.niux.data.vipgame.bo.*;
import com.xunlei.niux.data.vipgame.bo.account.PreRegisterAccountBo;
import com.xunlei.niux.data.vipgame.bo.activity.CompanyQqOpenRecordBo;
import com.xunlei.niux.data.vipgame.bo.activity.CouponBo;
import com.xunlei.niux.data.vipgame.bo.activity.secondkill.SecondKillConfigBo;
import com.xunlei.niux.data.vipgame.bo.authority.AuthInfoBo;
import com.xunlei.niux.data.vipgame.bo.bonus.AuctionProductBo;
import com.xunlei.niux.data.vipgame.bo.bonus.AuctionRecordBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BaseProductBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusChargeBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusChargeRecordBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusExchangeBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusOperateRecordBo;
import com.xunlei.niux.data.vipgame.bo.bonus.BonusProductGiveOutDayStatisticsBo;
import com.xunlei.niux.data.vipgame.bo.bonus.ExchangeTransBo;
import com.xunlei.niux.data.vipgame.bo.bonus.SignDayNumBo;
import com.xunlei.niux.data.vipgame.bo.bonus.SignRecordBo;
import com.xunlei.niux.data.vipgame.bo.boxThree.BoxBonusChargeBo;
import com.xunlei.niux.data.vipgame.bo.boxThree.BoxBonusChargeRecordBo;
import com.xunlei.niux.data.vipgame.bo.businesss.*;
import com.xunlei.niux.data.vipgame.bo.gamepoint.GamePointBo;
import com.xunlei.niux.data.vipgame.bo.gamepoint.UserGradePointBo;
import com.xunlei.niux.data.vipgame.bo.games.MobileGamePicBo;
import com.xunlei.niux.data.vipgame.bo.gift.GiftBo;
import com.xunlei.niux.data.vipgame.bo.gift.GiftRecordBo;
import com.xunlei.niux.data.vipgame.bo.gift.UseGiftPackageBo;
import com.xunlei.niux.data.vipgame.bo.jifenshop.JiFenRewardRecordBo;
import com.xunlei.niux.data.vipgame.bo.lottery.FortuneGiftBo;
import com.xunlei.niux.data.vipgame.bo.lottery.FreeLotteryChanceBo;
import com.xunlei.niux.data.vipgame.bo.lottery.LotteryRecordBo;
import com.xunlei.niux.data.vipgame.bo.moyu.*;
import com.xunlei.niux.data.vipgame.bo.openserver.OpenServerBo;
import com.xunlei.niux.data.vipgame.bo.pay.PayOrderBo;
import com.xunlei.niux.data.vipgame.bo.pay.RechargeRecordBo;
import com.xunlei.niux.data.vipgame.bo.tasks.TaskDutyConfigBo;
import com.xunlei.niux.data.vipgame.bo.tasks.TaskGameConfigBo;
import com.xunlei.niux.data.vipgame.bo.tasks.UserTaskRecordBo;
import com.xunlei.niux.data.vipgame.bo.version.GameVersionBo;
import com.xunlei.niux.data.vipgame.bo.version.VersionInfoBo;

import com.xunlei.niux.data.vipgame.bo.gift.GiftFlowBo;
import com.xunlei.niux.data.vipgame.bo.vic.CustomerBo;
import com.xunlei.niux.data.vipgame.bo.vic.KpiBo;
import com.xunlei.niux.data.vipgame.bo.vic.RebateReportBo;
import com.xunlei.niux.data.vipgame.bo.vic.SmsSendApplyBo;


public interface IFacade {
	CouponBo getCouponBo();
	FortuneBo getFortuneBo();
    GameContentBo getGameContentBo();
    UseGiftPackageBo getUseGiftPackageBo();
    GameImgBo getGameImgBo();

    GameExpandBo getGameExpandBo();

    GameScreenshotImageBo getGameScreenshotImageBo();

    GamesBo getGamesBo();

    GameServersBo getGameServersBo();

    SpreadinfoBo getSpreadinfoBo();

    PageStatisticsJsBo getPageStatisticsJsBo();

    LinkInfoBo getLinkInfoBo();

    LinkLocationBo getLinkLocationBo();

    HtmlTemplateBo getHtmlTemplateBo();

    TemplateSchemaBo getTemplateSchemaBo();

    SpreadInfoTimeBo getSpreadInfoTimeBo();

    GamePayInfoBo getGamePayInfoBo();

    GameInsideplaceBo getGameInsideplaceBo();

    UserFeedbackBo getUserFeedbackBo();

    MoyoServerBo getMoyoServerBo();

    MoyuActBo getMoyuActBo();

    MoyuJiFenBo getMoyuJiFenBo();

    MoyuJiFenHistoryBo getMoyuJiFenHistoryBo();
    
    InterfaceManBo getInterfaceManBo();
    
    CallRecordBo getCallRecordBo();
    
    ChargeAmountProfileSettingsBo getChargeAmountProfileSettingsBo();

    MoyuExchangeBo getMoyuExchangeBo();
    TempPasswordBo getTempPasswordBo();
    ForbidUserBo getForbidUserBo();

    MoyuGiftBo getMoyuGiftBo();

    MoyuReportBo getMoyuReportBo();
    
    BigCustomerQueryBo getBigCustomerQueryBo();
    
    BigCustomerDetailBo getBigCustomerDetailBo();

    MoyuTotalReportBo getMoyuTotalReportBo();
    MoyuDayReportBo getMoyuDayReportBo();
    MoyuDetailReportBo getMoyuDetailReportBo();

    CorporationInfoBo getCorporationInfoBo();
    ResponsiblePeopleBo getResponsiblePeopleBo();
    TestAcountBo getTestAcountBo();
    IntoSystemBo getIntoSystemBo();
    IncomeBo getIncomeBo();
    IncomeAppBo getIncomeAppBo();
    TestIncomeBo getTestIncomeBo();

    SendMailRecordBo getSendMailRecordBo();
    ActivityBo getActivityBo();
    BigActVoteDetailBo getBigActVoteDetailBo();
    QuestionSettingsBo getQuestionSettingsBo();
    QuestionBo getQuestionBo();
    QuestionReplyBo getQuestionReplyBo();
    QuestionItemBo getQuestionItemBo();
    QuestionGameCategoryBo getQuestionGameCategoryBo();
    GameCategoryBo getGameCategoryBo();
    PayOrderBo getPayOrderBo();
    RechargeRecordBo getRechargeRecordBo();
    UserInfoExpandBo getUserInfoExpandBo();
    AdviceBo getAdviceBo();

    PrizeBo getPrizeBo();
    SignRecordBo getSignRecordBo();
    BonusProductBo getBonusProductBo();
    BonusChargeRecordBo getBonusChargeRecordBo();
    BonusOperateRecordBo getBonusOperateRecordBo();
    BonusChargeBo getBonusChargeBo();
    SignDayNumBo getSignDayNumBo();
    ExchangeTransBo getExchangeTransBo();
    BonusProductGiveOutDayStatisticsBo getBonusProductGiveOutDayStatisticsBo();
    WhiteListBo getWhiteListBo();
    CustomerGradeBo getCustomerGradeBo();
    CustomerPayBo getCustomerPayBo();
    CustomerPersistBo getCustomerPersistBo();
    CustomerTotalBo getCustomerTotalBo();
    CustomerQueryBo getCustomerQueryBo();
    CustomerInfoBo getCustomerInfoBo();
    CustomerDetailQueryBo getCustomerDetailQueryBo();
    CustomerBigPayQueryBo getCustomerBigPayQueryBo();
    MobileBindActBo getMobileBindActBo();
    VersionInfoBo getVersionInfoBo();
    GameVersionBo getGameVersionBo();
    FavoriteRecordBo getFavoriteRecordBo();
    CommonAskBo getCommonAskBo();
    YyQuestionBo getYyQuestionBo();
    CardDistributionBo getCardDistributionBo();
    CardBiziBo getCardBiziBo();
    CardCountBo getCardCountBo();
    CardUseRecordBo getCardUseRecordBo();
    CardRecordDetailBo getCardRecordDetailBo();
    MessageBo getMessageBo();
    CounterAttackBo getCounterAttackBo();
    LiveCountBo getLiveCountBo();
    UserMessageBo getUserMessageBo();
    SignStatisticsBo getSignStatisticsBo();
    TimeTaskRecordBo getTimeTaskRecordBo();
    GameXmlMetaBo getGameXmlMetaBo();
    GamePayXmlMetaBo getGamePayXmlMetaBo();
    GameActivityXmlMetaBo getGameActivityXmlMetaBo();
    AutoProductBo getAutoProductBo();
    AutoCountBo getAutoCountBo();
    BlackIpBo getBlackIpBo();
    TestAccountBo getTestAccountBo();
    BonusLotRecordBo getBonusLotRecord();
    BonusExchangeBo getBonusExchangeBo();
    MemberGiftBo getMemberGiftBo();
    MemberReceiveBo getMemberReceiveBo();
    CheckUserBo getCheckUserBo();
    MarketProductBo getMarketProductBo();
    CompanyQqOpenRecordBo getCompanyQqOpenRecordBo();
    ActivityExchangeProductBo getActivityExchangeProductBo();
    ActivityExchangeRecordBo getActivityExchangeRecordBo();
    AuctionProductBo getAuctionProductBo();
    AuctionRecordBo getAuctionRecordBo();
    BaseProductBo getBaseProductBo();
    CustomerChangeInfoBo getCustomerChangeInfoBo();
    BaseSo getBaseSo();
    AuthInfoBo getAuthInfoBo();
    TriggerMessageBo getTriggerMessageBo();
    SeoLinkBo getSeoLinkBo();
    FortuneGiftBo getFortuneGiftBo();
    LotteryGiftBo getLotteryGiftBo();
    RebateOrderBo getRebateOrderBo();

    FreeLotteryChanceBo getFreeLotteryChanceBo();
    PreRegisterAccountBo getPreRegisterAccountBo();
    OpenServerBo getOpenServerBo();
    GiftRecordBo getGiftRecordBo();
    SecondKillConfigBo getSecondKillConfigBo();

    UserTaskRecordBo getUserTaskRecordBo();
    TaskDutyConfigBo getTaskDutyConfigBo();

    TaskGameConfigBo getTaskGameConfigBo();

    GiftBo getGiftBo();

    GiftFlowBo getGiftFlowBo();

    GamePointBo getGamePointBo();

    UserGradePointBo getUserGradePointBo();

    LotteryRecordBo getLotteryRecordBo();

    JiFenRewardRecordBo getJiFenRewardRecordBo();

    MobileGamePicBo getMobileGamePicBo();

    KpiBo getKpiBo();

    RebateReportBo getRebateReportBo();

    SmsSendApplyBo getSmsSendApplyBo();

    CustomerBo getCustomerBo();
    
    BoxBonusChargeBo getBoxBonusChargeBo();
    BoxBonusChargeRecordBo getBoxBonusChargeRecordBo();
}
